@@ -1,6 +1,7 @@
 import shap
 import numpy as np
 import pandas as pd
+import os
 
 from isv.config import settings
 from isv.scripts.prepare_df import prepare
@@ -14,10 +15,11 @@ def shap_values_with_same_cnv_type(annotated_cnvs: pd.DataFrame, cnv_type: str,
     :param annotated_cnvs: Raw counts of genomic elements
     :param cnv_type: type of cnv
     :param raw: whether raw shap explainer object should be returned
+
     :return: explainer object
     """
     X, X_train = prepare(annotated_cnvs, cnv_type, return_train=True)
-    model = open_model(settings.model_dir + f'ISV_{cnv_type}.json')
+    model = open_model(os.path.join(settings.model_dir, f'ISV_{cnv_type}.json'))
 
     explainer = shap.TreeExplainer(
         model,
@@ -36,6 +38,7 @@ def shap_values(annotated_cnvs: pd.DataFrame):
     """Calculate SHAP values
 
     :param annotated_cnvs: annotated cnvs
+
     :return: explainer object
     """
     del_ind = np.where(annotated_cnvs.cnv_type == "DEL")[0]
